<#
    .Synopsis
        open_in_swarm.ps1 opens the currently selected file in Swarm
 
    .Description
        This is intended as a custom tool for P4V.
        It is useful to easily open a file in default browser.
        It can be easily installed for P4V using Install-P4VUtils.ps1
 
    .Parameter p4port
        The P4PORT to use
 
    .Parameter p4user
        The P4USER to use
 
    .Parameter path
        The file to open
 
    .Example
        As custom tool in P4V:
 
        Application: powershell
        Arguments: -f c:\path\to\open_in_swarm.ps1 $p $u %d
 
        Where c:\path\to is the name of directory containing the script
 
        Check option “Run tool in terminal window”
       If not debugging, check option “Close window upon completion”
#>
 
# Doesn't work in older versions of Powershell
# [CmdletBinding()]
param ( [string]$p4port,
        [string]$p4user,
        [string]$path)
 
Function Log([string]$message) {
    # Logs output to file and to console
    $datetime = Get-Date -format "yyyy\/MM\/dd HH\:mm\:ss"
    "$datetime $message" | write-output
}
 
try {
    if ($p4port -eq $null -or $p4port -eq "") {
        throw "ERROR: please specify parameter p4port"
    }
    if ($p4user -eq $null -or $p4user -eq "") {
        throw "ERROR: please specify parameter p4user"
    }
    if ($path -eq $null -or $path -eq "") {
        throw "ERROR: please specify parameter depot_path"
    }
   
    $p4args = "-p", $p4port
    if ($p4user -ne "default") {
        $p4args += "-u", $p4user
    }
    $p4args += "property", "-l", "-n", "P4.Swarm.URL"
 
    Log "p4 $p4args"
    Log "depot_path $path"
    $result = & p4 @p4args
    Log finished
    Log "$result"
    $url = [regex]::match($result, '^P4.Swarm.URL = (\S+)$').Groups[1].Value
    Log "$url"
    $path = $path.substring(1)  # Remove leading /
    $enc = [uri]::EscapeUristring($path)
    $url = "$url/files$enc"
    Log "$url"
    start $url
    exit 0
}
Catch
{
   write-error $_.Exception
   exit 1
}
